@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # Copyright 2005 Eduardo Gonzalez
+#           2020 Roneel Valambhia
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,6 @@ from quodlibet.util import tag, escape
 from quodlibet.qltk.songlist import get_columns
 from quodlibet.qltk.chooser import choose_target_file
 from quodlibet.plugins.songsmenu import SongsMenuPlugin
-from quodlibet.compat import text_type
 
 
 HTML = '''<html>
@@ -25,7 +24,7 @@ HTML = '''<html>
  </style>
 </head>
 <body>
-  <h1>My <a href="http://www.sacredchao.net/quodlibet/">Quod Libet</a>
+  <h1>My <a href="https://quodlibet.readthedocs.io/">Quod Libet</a>
   Playlist</h1>
   <br />
   <table id="songTable">
@@ -55,7 +54,7 @@ def to_html(songs):
             col = {"~#rating": "~rating", "~#length": "~length"}.get(
                 col, col)
             s += '\n<td>%s</td>' % (
-                escape(text_type(song.comma(col))) or '&nbsp;')
+                escape(str(song.comma(col))) or '&nbsp;')
         s += '</tr>'
         songs_s += s
 
